"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _reactNativeInappbrowserReborn = _interopRequireDefault(require("react-native-inappbrowser-reborn"));

var _storage = _interopRequireDefault(require("./storage"));

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class RNAdapter {
  constructor(client, _keycloakConfig, initOptions) {
    _defineProperty(this, "client", void 0);

    _defineProperty(this, "initOptions", void 0);

    this.client = client;
    this.initOptions = initOptions;
  }

  createCallbackStorage() {
    return new _storage.default();
  }
  /**
   * Start login process
   *
   * @param {KeycloakLoginOptions} options Login options
   */


  async login(options) {
    const loginUrl = this.client.createLoginUrl(options);

    if (await _reactNativeInappbrowserReborn.default.isAvailable()) {
      // See for more details https://github.com/proyecto26/react-native-inappbrowser#authentication-flow-using-deep-linking
      const res = await _reactNativeInappbrowserReborn.default.openAuth(loginUrl, this.client.redirectUri, this.initOptions.inAppBrowserOptions);

      if (res.type === 'success' && res.url) {
        const oauth = this.client.parseCallback(res.url);
        return this.client.processCallback(oauth);
      }

      if (res.type === 'cancel') {
        throw new Error('User has closed the browser');
      }

      throw new Error('Authentication flow failed');
    } else {
      throw new Error('InAppBrowser not available'); // TODO: maybe!
      //   Linking.openURL(loginURL);
    }
  }

  async logout(options) {
    const logoutUrl = this.client.createLogoutUrl(options);

    if (await _reactNativeInappbrowserReborn.default.isAvailable()) {
      // See for more details https://github.com/proyecto26/react-native-inappbrowser#authentication-flow-using-deep-linking
      const res = await _reactNativeInappbrowserReborn.default.openAuth(logoutUrl, this.client.redirectUri, this.initOptions.inAppBrowserOptions);

      if (res.type === 'success') {
        return this.client.clearToken();
      }

      throw new Error('Logout flow failed');
    } else {
      throw new Error('InAppBrowser not available'); // TODO: maybe!
      //   Linking.openURL(logoutUrl);
    }
  }

  async register(options) {
    const registerUrl = this.client.createRegisterUrl(options);

    if (await _reactNativeInappbrowserReborn.default.isAvailable()) {
      // See for more details https://github.com/proyecto26/react-native-inappbrowser#authentication-flow-using-deep-linking
      const res = await _reactNativeInappbrowserReborn.default.openAuth(registerUrl, this.client.redirectUri, this.initOptions.inAppBrowserOptions);

      if (res.type === 'success' && res.url) {
        const oauth = this.client.parseCallback(res.url);
        return this.client.processCallback(oauth);
      }

      throw new Error('Registration flow failed');
    } else {
      throw new Error('InAppBrowser not available'); // TODO: maybe!
      //   Linking.openURL(registerUrl);
    }
  }

  async accountManagement() {
    const accountUrl = this.client.createAccountUrl();

    if (typeof accountUrl !== 'undefined') {
      await _reactNativeInappbrowserReborn.default.open(accountUrl, this.initOptions.inAppBrowserOptions);
    } else {
      throw 'Not supported by the OIDC server';
    }
  }

  async fetchKeycloakConfigJSON(configUrl) {
    return await (0, _utils.fetchJSON)(configUrl);
  }

  async fetchOIDCProviderConfigJSON(oidcProviderConfigUrl) {
    return await (0, _utils.fetchJSON)(oidcProviderConfigUrl);
  }

  async fetchTokens(tokenUrl, params) {
    const tokenRes = await fetch(tokenUrl, {
      method: 'POST',
      headers: {
        'Content-type': 'application/x-www-form-urlencoded'
      },
      body: params
    });
    if (!tokenRes.ok) throw new Error('fetchTokens failed');
    return await tokenRes.json();
  }

  async refreshTokens(tokenUrl, params) {
    const tokenRes = await fetch(tokenUrl, {
      method: 'POST',
      headers: {
        'Content-type': 'application/x-www-form-urlencoded'
      },
      body: params
    });
    if (!tokenRes.ok) throw new Error('refreshTokens failed');
    return await tokenRes.json();
  }

  async fetchUserProfile(profileUrl, token) {
    return await (0, _utils.fetchJSON)(profileUrl, token);
  }

  async fetchUserInfo(userInfoUrl, token) {
    return await (0, _utils.fetchJSON)(userInfoUrl, token);
  }

  redirectUri(options) {
    if (options && options.redirectUri) {
      return options.redirectUri;
    }

    if (this.client.redirectUri) {
      return this.client.redirectUri;
    }

    return ''; // TODO: Retrieve app deeplink
  }

}

var _default = RNAdapter;
exports.default = _default;
//# sourceMappingURL=adapter.js.map