import type { CallbackStorage, FetchTokenResponse, KeycloakAdapter, KeycloakConfig, KeycloakInstance, KeycloakJSON, KeycloakLoginOptions, KeycloakLogoutOptions, KeycloakProfile, KeycloakRegisterOptions, OIDCProviderConfig } from '@react-keycloak/keycloak-ts';
import type { RNKeycloakInitOptions } from './types';
declare class RNAdapter implements KeycloakAdapter {
    private readonly client;
    private readonly initOptions;
    constructor(client: Readonly<KeycloakInstance>, _keycloakConfig: Readonly<KeycloakConfig>, initOptions: Readonly<RNKeycloakInitOptions>);
    createCallbackStorage(): CallbackStorage;
    /**
     * Start login process
     *
     * @param {KeycloakLoginOptions} options Login options
     */
    login(options?: KeycloakLoginOptions): Promise<void>;
    logout(options?: KeycloakLogoutOptions): Promise<void>;
    register(options?: KeycloakRegisterOptions): Promise<void>;
    accountManagement(): Promise<void>;
    fetchKeycloakConfigJSON(configUrl: string): Promise<KeycloakJSON>;
    fetchOIDCProviderConfigJSON(oidcProviderConfigUrl: string): Promise<OIDCProviderConfig>;
    fetchTokens(tokenUrl: string, params: string): Promise<FetchTokenResponse>;
    refreshTokens(tokenUrl: string, params: string): Promise<FetchTokenResponse>;
    fetchUserProfile(profileUrl: string, token: string): Promise<KeycloakProfile>;
    fetchUserInfo(userInfoUrl: string, token: string): Promise<unknown>;
    redirectUri(options?: {
        redirectUri?: string;
    }): string;
}
export default RNAdapter;
